// This file is licensed under the terms of the CC-LGPL.
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas  
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escaz, San Jos, Costa Rica 
// dedicado a Jess y Mara...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 8 noviembre 2010
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
// El objeto ATPD_AsientoTerrazaPlasticoDomestico se coloca segun
// Minimo <  -350,      0,  -536>*L
// Maximo <   350,    536,    93>*L  
// con el centro inferior de las patas traseras en el origen
// y la silla orientada hacia z-, parte superior hacia y+
//
// acepta los siguientes modificadores
//   #declare ATPD_TexturaAsientoMetal = texture {...}
//             para el metal de la estrutura de soporte
//   #declare ATPD_TexturaMangoSilla   = texture {...}
//             para el manto de la silla
//   #declare ATPD_CuerdaBlanco = texture {...}
//             para las cuerdas plasticas de color blanco
//   #declare ATPD_CuerdaRojo   = texture {...}
//             para las cuerdas plasticas de color rojo
//
// Para colocarlo simplemente 
// #include "AsientoTPD.inc"
// object { ATPD_AsientoTerrazaPlasticoDomestico } 
// o con modificadores podria crearse una silla infantil...      
// #declare ATPD_TexturaAsientoMetal = texture {pigment{color Red}}
// #declare ATPD_TexturaMangoSilla   = texture {pigment{color Yellow}}
// #declare ATPD_CuerdaBlanco = texture {pigment{color Blue}}
// #declare ATPD_CuerdaRojo   = texture {pigment{color Green}}
// #include "AsientoTPD.inc"
// object { ATPD_AsientoTerrazaPlasticoDomestico scale 0.75 }
//

#include "colors.inc"  
#include "transforms.inc"
#include "metals.inc"  
#local L                      = 0.001;
  
#ifndef ( ATPD_TexturaAsientoMetal )
  #local ATPD_TexturaAsientoMetal       = texture       {
    pigment     { color Silver }
    normal      {
      bumps   bump_size  2.0
    }
    finish      {    
      phong     0.1
      metallic  0.5
    }
  }
#end 

#ifndef ( ATPD_TexturaMangoSilla )
  #local ATPD_TexturaMangoSilla         = texture       {
    pigment     { color Red }
    normal      { bumps bump_size 1.0 }
  }
#end  

#ifndef ( ATPD_CuerdaBlanco )
  #local ATPD_CuerdaBlanco              = texture       {
    pigment     { color White }
  }
#end

#ifndef ( ATPD_CuerdaRojo )
  #local ATPD_CuerdaRojo                = texture       {
    pigment     { color Red }
  }  
#end

// Datos de spline                          
#local AsientoMaximo                    = < 458, 247,   0>*L;
#local FinalAsientoMaximo               = < 430, 135,   0>*L;
#local LargoAsientoMaximo               = vlength( AsientoMaximo );
#local DiametroFinalAsientoMaximo       = 85*L;
#local LargoFinalAsientoMaximo          =
          LargoAsientoMaximo+pi*DiametroFinalAsientoMaximo*2; 
#local SeparacionSoporte                = 458*L; 
#local SoporteMaximo                    = <- 57, 515,   0>*L;
#local LargoSoporteMaximo               = vlength( SoporteMaximo );
#local LargoFinalSoporteMaximo          =
          LargoSoporteMaximo+pi*DiametroFinalAsientoMaximo/2;
#local FinalSoporteMaximo               = <- 72, 450,   0>*L;
#local CruceSoporte                     = 
                288*L/LargoAsientoMaximo*AsientoMaximo;
#local LargoCruce                       = vlength( CruceSoporte );
#local InicioSoporte                    = < SeparacionSoporte, 0, 0 >;
#local LargoCruceSoporte                = 
                        vlength( CruceSoporte-InicioSoporte );
                      

#local SplineAsiento    = spline        {  
  cubic_spline
  -LargoCruce                   , -CruceSoporte
  0                             , <0,0,0>
  LargoCruce                    , CruceSoporte
  LargoAsientoMaximo            , AsientoMaximo
  LargoFinalAsientoMaximo       , FinalAsientoMaximo                            
  LargoFinalAsientoMaximo+vlength( FinalAsientoMaximo )/2
                                , FinalAsientoMaximo/2
}

#local SplineRespaldo   = spline        {
  cubic_spline      
  -2*LargoCruceSoporte          ,
                (3*< SeparacionSoporte, 0, 0 >-2*CruceSoporte),
  -LargoCruceSoporte            , 
                2*< SeparacionSoporte, 0, 0 >-CruceSoporte,
  0                             , < SeparacionSoporte, 0, 0 >
  LargoCruceSoporte             , CruceSoporte
  LargoSoporteMaximo            , SoporteMaximo
  LargoFinalSoporteMaximo       , FinalSoporteMaximo
  LargoFinalSoporteMaximo+vlength( FinalSoporteMaximo )/2
                                , FinalSoporteMaximo/2 
  LargoFinalSoporteMaximo+vlength( FinalSoporteMaximo)
                                , <0,0,0>
  // note que este punto de control esta referido al origen
  // y no al punto 0 de spline ( ver dibujo )
}

// Datos de Diametros, y separaciones
#local DiametroTuboUsual        = 18*L;
#local DiametroUnionFina        = 12*L;
#local DiametroUnionCruce       = 14*L;
#local DiametroTuboSoporte      = 16*L;

#local TotalEsferasAsiento      = 10;
#local DesplazamientoEsferasAsiento             = 
        LargoFinalAsientoMaximo/( TotalEsferasAsiento-1 );
#local TotalEsferasSoporte      = 10;
#local DesplazamientoEsferasSoporte             = 
        LargoFinalSoporteMaximo/( TotalEsferasSoporte-1 );

#local TuboBaseAsiento          = sphere_sweep  {
   cubic_spline
   TotalEsferasAsiento+2,
   #local LargoEsfera           = -DesplazamientoEsferasAsiento;
   #local B                     = 0;
   #while ( B < ( TotalEsferasAsiento+2 ) )
     SplineAsiento( LargoEsfera ), DiametroTuboUsual/2
     #local B                   = B+1;
     #local LargoEsfera         = LargoEsfera+DesplazamientoEsferasAsiento;
   #end    
}

#local TuboBaseSoporte          = sphere_sweep  {
   cubic_spline
   TotalEsferasSoporte+2,
   #local LargoEsfera           = -DesplazamientoEsferasSoporte;
   #local B                     = 0;
   #while ( B < ( TotalEsferasSoporte+2 ) )
     SplineRespaldo( LargoEsfera ), DiametroTuboUsual/2
     #local B                   = B+1;
     #local LargoEsfera         = LargoEsfera+DesplazamientoEsferasSoporte;
   #end
   tolerance            1.0e-10
}  

#local SeparacionAsiento        = 300*L; 
#local SeparacionSoporte        = SeparacionAsiento+2*DiametroTuboUsual; 
#local EjeSoporteFino           = 70*L;    
#local EjeAsientoFino           = 71*L;
#local EjeCruce1                = 307*L;
#local RedondeCruce1            = <   0,- 19,- 19>*L;
#local EjeCruce2                = 221*L; 
#local EjeCruce3                = 250*L;

#local BaseAsiento              = union         {
  object        {
    TuboBaseAsiento
    rotate      90*y
    translate   -SeparacionAsiento/2*x
  }
  object        {
    TuboBaseAsiento
    rotate      90*y
    translate   +SeparacionAsiento/2*x
  }  
  cylinder      {
    vtransform( SplineAsiento( EjeSoporteFino ), 
        transform{ rotate 90*y translate -SeparacionAsiento/2*x } ),
    vtransform( SplineAsiento( EjeSoporteFino ), 
        transform{ rotate 90*y translate +SeparacionAsiento/2*x } ),
    DiametroUnionFina/2
  }
  cylinder      {
    vtransform( FinalAsientoMaximo, 
        transform{ rotate 90*y translate -SeparacionAsiento/2*x } ),
    vtransform( FinalAsientoMaximo, 
        transform{ rotate 90*y translate +SeparacionAsiento/2*x } ),
    DiametroTuboSoporte/2
  }
  sphere_sweep  {
    cubic_spline
    5,
    #local BaseEje      = 
        vtransform(SplineAsiento( EjeCruce1 ), 
        transform{ 
          rotate 90*y 
          translate -( DiametroTuboUsual+DiametroUnionCruce )/2*y } );
    #local PuntoCentro  = BaseEje+RedondeCruce1;  
    #local CorreccionLado       = <+SeparacionAsiento/2,0,0>;
    2*BaseEje-PuntoCentro-2*CorreccionLado
                            ,   DiametroUnionCruce/2,    
    BaseEje-CorreccionLado  ,   DiametroUnionCruce/2,
    PuntoCentro             ,   DiametroUnionCruce/2,
    BaseEje+CorreccionLado  ,   DiametroUnionCruce/2,
    2*BaseEje-PuntoCentro+2*CorreccionLado
                            ,   DiametroUnionCruce/2    
  } 
  texture       {
    ATPD_TexturaAsientoMetal
  }
}

#local BaseSoporte              = union         {
  object        {
    TuboBaseSoporte
    rotate      90*y
    translate   -SeparacionSoporte/2*x
  }
  object        {
    TuboBaseSoporte
    rotate      90*y
    translate   +SeparacionSoporte/2*x
  }
  cylinder      {
    vtransform( SplineRespaldo( EjeAsientoFino ), 
        transform{ rotate 90*y translate -SeparacionSoporte/2*x } ),
    vtransform( SplineRespaldo( EjeAsientoFino ), 
        transform{ rotate 90*y translate +SeparacionSoporte/2*x } ),
    DiametroUnionFina/2
  }
  cylinder      {
    vtransform( FinalSoporteMaximo, 
        transform{ rotate 90*y translate -SeparacionSoporte/2*x } ),
    vtransform( FinalSoporteMaximo, 
        transform{ rotate 90*y translate +SeparacionSoporte/2*x } ),
    DiametroTuboSoporte/2
  }
  sphere_sweep  {
    cubic_spline
    5,
    #local BaseEje      = 
        vtransform(SplineRespaldo( EjeCruce2 ), 
        transform{ 
          rotate 90*y 
          translate +( DiametroTuboUsual+DiametroUnionCruce )/2*y } );
    #local PuntoCentro  = BaseEje+RedondeCruce1;  
    #local CorreccionLado       = <+SeparacionSoporte/2,0,0>;
    2*BaseEje-PuntoCentro-2*CorreccionLado
                            ,   DiametroUnionCruce/2,    
    BaseEje-CorreccionLado  ,   DiametroUnionCruce/2,
    PuntoCentro             ,   DiametroUnionCruce/2,
    BaseEje+CorreccionLado  ,   DiametroUnionCruce/2,
    2*BaseEje-PuntoCentro+2*CorreccionLado
                            ,   DiametroUnionCruce/2    
  } 
  sphere_sweep  {
    cubic_spline
    5,
    #local BaseEje      = 
        vtransform(SplineRespaldo( EjeCruce3 ), 
        transform{ 
          rotate 90*y 
          translate +( DiametroTuboUsual+DiametroUnionCruce )/2*y } );
    #local PuntoCentro  = BaseEje-RedondeCruce1;  
    #local CorreccionLado       = <+SeparacionSoporte/2,0,0>;
    2*BaseEje-PuntoCentro-2*CorreccionLado
                            ,   DiametroUnionCruce/2,    
    BaseEje-CorreccionLado  ,   DiametroUnionCruce/2,
    PuntoCentro             ,   DiametroUnionCruce/2,
    BaseEje+CorreccionLado  ,   DiametroUnionCruce/2,
    2*BaseEje-PuntoCentro+2*CorreccionLado
                            ,   DiametroUnionCruce/2    
  } 
  texture       {
    ATPD_TexturaAsientoMetal
  }
}

#local InicioTorusAsiento       = 320*L;  
#local InicioTorusRespaldo      = 270*L;
#local S                        = seed( 1011 );
#local FactorErrorDesplazamiento        = 0.1;
#local DiametroMenorTorus       = 5*L;
#local SeguridadOblicua         = 20*L;  
                             
#local LargoMango               = 214*L;
#local ProfundidadMango         = 30*L;
#local AnchoMaxMango            = 50*L;
#local BaseInferiorMango        = SplineRespaldo( 286*L );
#local BaseSuperiorMango        = SplineRespaldo( 350*L );
#local BaseLargoMango           = 
                BaseSuperiorMango+<LargoMango,0,ProfundidadMango>;
      
#local SplineMango      = spline        {
  cubic_spline
  -1    , BaseInferiorMango-LargoMango*x
  0     , BaseInferiorMango
  1     , BaseLargoMango
  2     , BaseSuperiorMango
  3     , BaseSuperiorMango-LargoMango*x
}      

#local ATPD_AnchoMango = function( ParametroSpline )       {
  select( ParametroSpline-1, (ParametroSpline*0.8+0.2)*AnchoMaxMango,
        AnchoMaxMango, ((2-ParametroSpline)*0.8+0.2)*AnchoMaxMango ) 
}


#macro ATPD_TorusMango( Centro, Ancho )   
  superellipsoid        {
    < 0.9,0.9 >
    scale       <DiametroMenorTorus/2,
        (DiametroMenorTorus+DiametroTuboUsual)/2,Ancho/2>
    translate   Centro
  }
#end 
      
#local CuerdasTorusAsiento = union     {
  #local RecorreTorus           = InicioTorusAsiento;
  #local CuentaTorus            = 0;  
  #local FactorCorOblicuo       = 1.0;
  #local BanderaOblicuo         = true; 
  #local CuentaFeoOblicuo       = 0;
  #while ( RecorreTorus < LargoFinalAsientoMaximo ) 
    union       {
      torus       {
        ( DiametroTuboUsual+DiametroMenorTorus*(1+0.1*rand(S) ) )/2,
        DiametroMenorTorus*(1+0.1*rand(S))/2  
        rotate    90*x  
        Spline_Trans( SplineAsiento, RecorreTorus, y, 0.1, 0.1 )
        rotate    90*y
        translate <-SeparacionAsiento/2,0,0>
      }
      torus       {
        ( DiametroTuboUsual+DiametroMenorTorus )/2,
        DiametroMenorTorus/2  
        rotate    90*x  
        Spline_Trans( SplineAsiento, RecorreTorus, y, 0.1, 0.1 )
        rotate    90*y
        translate <+SeparacionAsiento/2,0,0>
      }
      #if ( ( RecorreTorus < ( LargoFinalAsientoMaximo-SeguridadOblicua ) )
                 & ( CuentaTorus  > 4 ) & BanderaOblicuo )
         #local CuentaTorus     = 0;
         cylinder       {
           <-SeparacionAsiento,+DiametroTuboUsual+DiametroMenorTorus,0>/2,
           <+SeparacionAsiento,+DiametroTuboUsual+DiametroMenorTorus,0>/2,
           DiametroMenorTorus/2
           rotate       FactorCorOblicuo*(1+rand(S))*y
           Spline_Trans( SplineAsiento, RecorreTorus, y, 0.1, 0.1 )
           rotate  90*y
         }   
         cylinder       {
           <-SeparacionAsiento,-DiametroTuboUsual-DiametroMenorTorus,0>/2,
           <+SeparacionAsiento,-DiametroTuboUsual-DiametroMenorTorus,0>/2,
           DiametroMenorTorus/2
           rotate       -FactorCorOblicuo*(1+rand(S))*y
           Spline_Trans( SplineAsiento, RecorreTorus, y, 0.1, 0.1 )
           rotate  90*y
         }   
      #end
      #switch ( RecorreTorus )
        #range ( InicioTorusAsiento, 
                (InicioTorusAsiento+LargoAsientoMaximo)/2 )
          texture       { ATPD_CuerdaBlanco }
          #local DesplazarTorus = DiametroMenorTorus;
        #break
        #range ( (InicioTorusAsiento+LargoAsientoMaximo)/2, 
                LargoAsientoMaximo )
          texture       { ATPD_CuerdaRojo }
          #local DesplazarTorus = DiametroMenorTorus;
        #break 
        #range ( LargoAsientoMaximo, 
                ( LargoAsientoMaximo+LargoFinalAsientoMaximo )/2 )
          texture       { ATPD_CuerdaBlanco }
          #local DesplazarTorus = 3*DiametroMenorTorus;
          #local CuentaFeoOblicuo = CuentaFeoOblicuo+1;
          #if ( CuentaFeoOblicuo >  4 )
            #local BanderaOblicuo = false;
          #end
          #if ( CuentaFeoOblicuo > 20 )
            #local BanderaOblicuo = true;
          #end
        #break
        #range ( ( LargoAsientoMaximo+LargoFinalAsientoMaximo )/2, 
                        LargoFinalAsientoMaximo )
          texture       { ATPD_CuerdaBlanco }
          #local DesplazarTorus = 2*DiametroMenorTorus;
          #local BanderaOblicuo = true;              
        #break
      #end
    }
    #local RecorreTorus         = RecorreTorus+
        DesplazarTorus*( 1+FactorErrorDesplazamiento*rand(S) );
    #local CuentaTorus          = CuentaTorus+1;
  #end
  #local InicioBarraFinal       = FinalAsientoMaximo;
  #local InicioBarraFinal       = vtransform( FinalAsientoMaximo,
        transform { rotate 90*y translate -SeparacionAsiento/2*x } );  
  #local DesplazadoFinal        = DiametroTuboUsual;
  #while ( DesplazadoFinal< ( SeparacionAsiento-0.5*DiametroTuboUsual ) )
    torus       {   
      DiametroTuboSoporte/2+DiametroMenorTorus*(1+0.1*rand(S))/2,
      DiametroMenorTorus/2*(1+0.1*rand(S))
      rotate    90*z
      translate InicioBarraFinal+DesplazadoFinal*x
      texture   { ATPD_CuerdaRojo }
    } 
    #local DesplazadoFinal      = DesplazadoFinal+
        DiametroMenorTorus*(1+0.1*rand(S));
  #end
}

#local CuerdasTorusRespaldo     = union {  
  #local RecorreTorus           = InicioTorusRespaldo;  
  #local CuentaTorus            = 0;
  #local FactorCorOblicuo       = 1.0;    
  #local BanderaOblicuo         = true; 
  #local CuentaFeoOblicuo       = 0;
  #while ( RecorreTorus < LargoFinalSoporteMaximo ) 
    union       {
      torus       {
        ( DiametroTuboSoporte+DiametroMenorTorus*(1+0.1*rand(S) ) )/2,
        DiametroMenorTorus*(1+0.1*rand(S))/2  
        rotate    90*x  
        Spline_Trans( SplineRespaldo, RecorreTorus, y, 0.1, 0.1 )
        rotate    90*y
        translate <-SeparacionSoporte/2,0,0>
      }
      torus       {
        ( DiametroTuboSoporte+DiametroMenorTorus )/2,
        DiametroMenorTorus/2  
        rotate    90*x  
        Spline_Trans( SplineRespaldo, RecorreTorus, y, 0.1, 0.1 )
        rotate    90*y
        translate <+SeparacionSoporte/2,0,0>
      }
      #if ( ( RecorreTorus < ( LargoFinalSoporteMaximo-SeguridadOblicua ) )
                 & ( CuentaTorus  = 4 ) & BanderaOblicuo )                                                          
         #local CuentaTorus     = 0;
         cylinder       {
           <-SeparacionSoporte,+DiametroTuboUsual+DiametroMenorTorus,0>/2,
           <+SeparacionSoporte,+DiametroTuboUsual+DiametroMenorTorus,0>/2,
           DiametroMenorTorus/2
           rotate       FactorCorOblicuo*(1+rand(S))*y
           Spline_Trans( SplineRespaldo, RecorreTorus, y, 0.1, 0.1 )
           rotate  90*y
         }   
         cylinder       {
           <-SeparacionSoporte,-DiametroTuboUsual-DiametroMenorTorus,0>/2,
           <+SeparacionSoporte,-DiametroTuboUsual-DiametroMenorTorus,0>/2,
           DiametroMenorTorus/2
           rotate       -FactorCorOblicuo*(1+rand(S))*y
           Spline_Trans( SplineRespaldo, RecorreTorus, y, 0.1, 0.1 )
           rotate  90*y
         }   
      #end
      #switch ( RecorreTorus )
        #range ( InicioTorusRespaldo, 
                (2*InicioTorusRespaldo+LargoSoporteMaximo)/3 )
          texture       { ATPD_CuerdaBlanco }
          #local DesplazarTorus = 0.5*DiametroMenorTorus;
        #break
        #range ( (2*InicioTorusRespaldo+LargoSoporteMaximo)/3, 
                (InicioTorusRespaldo+2*LargoSoporteMaximo)/3 )
          texture       { ATPD_CuerdaRojo }
          #local DesplazarTorus = 0.5*DiametroMenorTorus;  
        #break 
        #range ((InicioTorusRespaldo+2*LargoSoporteMaximo)/3, 
                ( LargoSoporteMaximo+LargoFinalSoporteMaximo )/2 )
          texture       { ATPD_CuerdaBlanco }
          #local DesplazarTorus = 1.0*DiametroMenorTorus;
          #local CuentaFeoOblicuo       = CuentaFeoOblicuo+1;
          #if ( ( CuentaFeoOblicuo > 20 ) & ( CuentaFeoOblicuo < 28 ) )
            #local BanderaOblicuo = false; 
          #else
            #local BanderaOblicuo = true;
          #end
        #break
        #range ( ( LargoSoporteMaximo+LargoFinalSoporteMaximo )/2, 
                        LargoFinalSoporteMaximo )
          texture       { ATPD_CuerdaBlanco }
          #local DesplazarTorus = 2*DiametroMenorTorus;              
          #local BanderaOblicuo = true;
        #break
      #end
    }
    #local RecorreTorus         = RecorreTorus+
        DesplazarTorus*( 1+FactorErrorDesplazamiento*rand(S) );
    #local CuentaTorus          = CuentaTorus+1;
  #end
  #local InicioBarraFinal       = FinalSoporteMaximo;
  #local InicioBarraFinal       = vtransform( FinalSoporteMaximo,
        transform { rotate 90*y translate -SeparacionSoporte/2*x } );  
  #local DesplazadoFinal        = DiametroTuboUsual;
  #while ( DesplazadoFinal< ( SeparacionSoporte-0.5*DiametroTuboUsual ) )
    torus       {   
      DiametroTuboSoporte/2+DiametroMenorTorus*(1+0.1*rand(S))/2,
      DiametroMenorTorus/2*(1+0.1*rand(S))
      rotate    90*z
      translate InicioBarraFinal+DesplazadoFinal*x
      texture   { ATPD_CuerdaRojo }
    } 
    #local DesplazadoFinal      = DesplazadoFinal+
        DiametroMenorTorus*(1+0.1*rand(S));
  #end          
  #union        {
  #local RecorreMango   = 0;
  #while ( RecorreMango < 2 )
    #local PivoteMango  = SplineMango(RecorreMango);
    object      {
      ATPD_TorusMango( PivoteMango, ATPD_AnchoMango( RecorreMango ) )
      translate +SeparacionSoporte/2*z
    } 
    object      {
      ATPD_TorusMango(vtransform( PivoteMango, 
        transform {scale <1,1,-1>} ), ATPD_AnchoMango( RecorreMango ) )
      translate -SeparacionSoporte/2*z
    }
    #local RecorreMango = RecorreMango+0.025;
  #end
    rotate      90*y   
    texture     {
      ATPD_TexturaMangoSilla
    }                       
  }
}

   
#declare ATPD_AsientoTerrazaPlasticoDomestico   = union   { 
  union {
    object { BaseAsiento          }
    object { CuerdasTorusAsiento  }
  }
  union {
    object { BaseSoporte          }
    object { CuerdasTorusRespaldo }
  }
  translate     +DiametroTuboUsual/2*y
}
