// This file is licensed under the terms of the CC-LGPL.
//
// El delfin fue creado originalmente con el programa
// "Blob Sculptor 2.0b" de AlfonsoHermida y otros (The Blob Team)
// ultima version en 1994
// compatible FreeDOS y WindowsXP
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com
// Apdo. 964-1250 Escaz, San Jos, Costa Rica 
// dedicado a Jess y Mara...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 22 noviembre 2010
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
// El objeto creado por la macro es un delfin.  Se ubica
// segun DSOT_DelfinSportOceanTravel(0,0,0,0,0) tiene coordenadas
// Minimo <  -736,   -255,  -322>*L
// Maximo <  1114,    325,   324>*L
// el origen se encuentra debajo de la parte delantera
// de la aleta dorsal, en el interior
//
// Los parametros de la macro
// DSOT_DelfinSportOceanTravel
//        ( AnguloSelfCola, SitaColeteo, FiColeteo,  
//                AnguloDerecho, AnguloIzquierdo ) 
// AnguloSelfCola       : rotacion de la cola sobre su propio eje
// SitaColeteo          : define el angulo o sentido del coleteo
//              si es igual a 0, el EjeRotacion es y+
//              el angulo Sita Coleteo gira "EjeRotacion" 
// FiColeteo            : establece el giro en el EjeRotacion
// AnguloDerecho        : giro de la aleta lateral derecha (del delfin)
//              en x+
// AnguloIzquierdo      : giro de la aleta lateral izquierda (del delfin)
//              en x+ 
//
// acepta los siguientes modificadores
//   #declare DSOT_PielBasica           = texture {...}
//             para la textura de la piel
//   #declare DSOT_ColorBajoAbdomen     = color
// Lamentablemente el ColorBajoAbdomen, se permite unicamente como color
// sin modificadores.
//   #declare DSOT_POV3_1               = on;
// Provoca simplificaciones para garantizar compatibilidad con POVRay3.1.
// En algunas versiones de POVRay se activa automticamente.
//
// Para colocarlo simplemente 
// #include "DSOT.inc"
// object       {
//   DSOT_DelfinSportOceanTravel(0,0,0,0,0)
// }
// o con modificadores podria un delfin de abdomen mas blanco...
// #declare DSOT_ColorBajoAbdomen       = color Gray50;
// #declare DSOT_PielBasica             = texture { 
//        pigment {color DimGray} 
// }
// #include "DelfinSOT.inc"
// object       {
//   DSOT_DelfinSportOceanTravel(0,0,0,0,0)
// }
// una simple animacion de coleteo sube y baja
// #include "DelfinSOT.inc"
// object       {
//   DSOT_DelfinSportOceanTravel
//        (0,90,20*sin(2*pi*clock),20*sin(2*pi*clock),20*sin(2*pi*clock))
// } 
// Nota: el noventa gira el EjeRotacion, para producir el coleteo
//      sube y baja, si 0 seria coleteo de izquierda a derecha
//


#include "colors.inc" 

#ifndef ( DSOT_POV3_1 )  
  #if ( version < 3.2 )
    #declare DSOT_POV3_1        = on;
  #else 
    #declare DSOT_POV3_1        = off;
  #end
#end  

#ifndef ( DSOT_PielBasica )
  #declare DSOT_PielBasica              = texture       {
    pigment     { color DarkSlateGray }
    finish { ambient 0.3 diffuse 0.7 }
  }
#end 

#ifndef ( DSOT_ColorBajoAbdomen )
  #declare DSOT_ColorBajoAbdomen        = color DimGray;
#end

#macro DSOT_DelfinSportOceanTravel
        ( AnguloSelfCola, SitaColeteo, FiColeteo,  
                AnguloDerecho, AnguloIzquierdo ) 
#macro DSOT_Giro( PosX, PosY, PosZ )
  #if ( PosX <= 0 )
    <PosX, PosY,PosZ>
  #else
    #local Pivote       = vrotate
                (<PosX,PosY,PosZ>,<PosX*AnguloSelfCola,0,0>);
    #if ( FiColeteo = 0 )
      Pivote
    #else
      #local EjeColeteo   = vrotate(y,<SitaColeteo,0,0>);
      #local Pivote       = 
                vaxis_rotate( Pivote, EjeColeteo, PosX*FiColeteo );
      #local FCol         = abs( FiColeteo );         
      #local FactorContraccion  =
        2*sqrt( 2*(1-cos(radians(FCol/2))) )/radians(FCol);
      FactorContraccion*Pivote
    #end
  #end
#end              
                
union   {
blob {
   threshold 0.6
   component 1.050000, 0.243407, DSOT_Giro( 0,0,0)
   component 1.050000, 0.127746, DSOT_Giro(0.000000, 0.000000, 0.075000)
   component 1.050000, 0.127746, DSOT_Giro(0.000000, 0.000000, -0.075000)
   component 1.050000, 0.158938, DSOT_Giro(0.000000, 0.075000, 0.000000)
   component 1.050000, 0.243407, DSOT_Giro(0.103376, -0.010549, 0.000000)
   component 1.050000, 0.127746, DSOT_Giro(0.103376, -0.010549, -0.075000)
   component 1.050000, 0.127746, DSOT_Giro(0.107595, -0.014768, 0.075000)
   component 1.050000, 0.158938, DSOT_Giro(0.099156, 0.073840, 0.000000)
   component 1.050000, 0.248535, DSOT_Giro(-0.103376, -0.006329, 0.000000)
   component 1.050000, 0.127746, DSOT_Giro(-0.094937, -0.010549, -0.075000)
   component 1.050000, 0.158938, DSOT_Giro(-0.090717, 0.073840, 0.000000)
   component 1.050000, 0.127746, DSOT_Giro(-0.103376, -0.014768, 0.073840)
   component 1.050000, 0.243407, DSOT_Giro(-0.200000, 0.000000, 0.000000)
   component 1.050000, 0.127746, DSOT_Giro(-0.200000, 0.000000, 0.075000)
   component 1.050000, 0.127746, DSOT_Giro(-0.200000, 0.000000, -0.075000)
   component 1.050000, 0.158938, DSOT_Giro(-0.200000, 0.075000, 0.000000)
   component 1.050000, 0.221067, DSOT_Giro(-0.300000, 0.000000, 0.000000)
   component 1.050000, 0.115976, DSOT_Giro(-0.300000, 0.000000, 0.067500)
   component 1.050000, 0.115976, DSOT_Giro(-0.300000, 0.000000, -0.067500)
   component 1.050000, 0.144018, DSOT_Giro(-0.300000, 0.067500, 0.000000)
   component 1.050000, 0.188707, DSOT_Giro(-0.400000, 0.000000, 0.000000)
   component 1.050000, 0.103166, DSOT_Giro(-0.400000, 0.000000, 0.060000)
   component 1.050000, 0.103166, DSOT_Giro(-0.400000, 0.000000, -0.060000)
   component 1.050000, 0.129138, DSOT_Giro(-0.400000, 0.060000, 0.000000)
   component 1.050000, 0.134113, DSOT_Giro(-0.500000, 0.000000, 0.000000)
   component 1.050000, 0.071413, DSOT_Giro(-0.500000, 0.000000, 0.041662)
   component 1.050000, 0.071413, DSOT_Giro(-0.500000, 0.000000, -0.041662)
   component 1.050000, 0.090742, DSOT_Giro(-0.500000, 0.041662, 0.000000)
   component 1.050000, 0.208564, DSOT_Giro(0.200000, 0.000000, 0.000000)
   component 1.050000, 0.114652, DSOT_Giro(0.200000, 0.000000, 0.066666)
   component 1.050000, 0.114652, DSOT_Giro(0.200000, 0.000000, -0.066666)
   component 1.050000, 0.142376, DSOT_Giro(0.200000, 0.066666, 0.000000)
   component 1.050000, 0.183743, DSOT_Giro(0.300000, 0.000000, 0.000000)
   component 1.050000, 0.100571, DSOT_Giro(0.300000, 0.000000, 0.058327)
   component 1.050000, 0.100571, DSOT_Giro(0.300000, 0.000000, -0.058327)
   component 1.050000, 0.125839, DSOT_Giro(0.300000, 0.058327, 0.000000)
   component 1.050000, 0.158936, DSOT_Giro(0.400000, 0.000000, 0.000000)
   component 1.050000, 0.078496, DSOT_Giro(0.400000, 0.000000, 0.050000)
   component 1.050000, 0.078496, DSOT_Giro(0.400000, 0.000000, -0.050000)
   component 1.050000, 0.099291, DSOT_Giro(0.400000, 0.050000, 0.000000)
   component 1.050000, 0.124113, DSOT_Giro(0.500000, 0.000000, 0.000000)
   component 1.050000, 0.065413, DSOT_Giro(0.500000, 0.000000, 0.041662)
   component 1.050000, 0.065413, DSOT_Giro(0.500000, 0.000000, -0.041662)
   component 1.050000, 0.082742, DSOT_Giro(0.500000, 0.041662, 0.000000)
   component 1.350000, 0.107407, DSOT_Giro(0.566666, 0.000000, 0.000000)
   component 1.350000, 0.056746, DSOT_Giro(0.566666, 0.000000, 0.036000)
   component 1.350000, 0.056746, DSOT_Giro(0.566666, 0.000000, -0.036000)
   component 1.350000, 0.071472, DSOT_Giro(0.566666, 0.036000, 0.000000)
   component 1.350000, 0.089367, DSOT_Giro(0.633333, 0.000000, 0.000000)
   component 1.350000, 0.047086, DSOT_Giro(0.633333, 0.000000, 0.030000)
   component 1.350000, 0.047086, DSOT_Giro(0.633333, 0.000000, -0.030000)
   component 1.350000, 0.059575, DSOT_Giro(0.633333, 0.030000, 0.000000)
   component 1.050000, 0.106070, DSOT_Giro(0.700000, 0.000000, 0.000000)
   component 1.050000, 0.039246, DSOT_Giro(0.700000, 0.000000, 0.025000)
   component 1.050000, 0.039246, DSOT_Giro(0.700000, 0.000000, -0.025000)
   component 1.050000, 0.049638, DSOT_Giro(0.700000, 0.025000, 0.000000)
   component 1.050000, 0.074307, DSOT_Giro(0.750000, 0.000000, 0.000000)
   component 1.050000, 0.039246, DSOT_Giro(0.750000, 0.000000, 0.025000)
   component 1.050000, 0.039246, DSOT_Giro(0.750000, 0.000000, -0.025000)
   component 1.050000, 0.049638, DSOT_Giro(0.750000, 0.025000, 0.000000)
   component 1.050000, 0.074307, DSOT_Giro(0.800000, 0.000000, 0.000000)
   component 1.050000, 0.039246, DSOT_Giro(0.800000, 0.000000, 0.025000)
   component 1.050000, 0.039246, DSOT_Giro(0.800000, 0.000000, -0.025000)
   component 1.050000, 0.049638, DSOT_Giro(0.800000, 0.025000, 0.000000)
   component 1.050000, 0.074307, DSOT_Giro(0.850000, 0.000000, 0.000000)
   component 1.050000, 0.039246, DSOT_Giro(0.850000, 0.000000, 0.025000)
   component 1.050000, 0.039246, DSOT_Giro(0.850000, 0.000000, -0.025000)
   component 1.050000, 0.049638, DSOT_Giro(0.850000, 0.025000, 0.000000)
   component 1.050000, 0.074307, DSOT_Giro(0.900000, 0.000000, 0.000000)
   component 1.050000, 0.039246, DSOT_Giro(0.900000, 0.000000, 0.025000)
   component 1.050000, 0.039246, DSOT_Giro(0.900000, 0.000000, -0.025000)
   component 1.050000, 0.049638, DSOT_Giro(0.900000, 0.025000, 0.000000)
   component 1.050000, 0.102186, DSOT_Giro(0.383460, -0.059409, 0.000000)
   component 1.050000, 0.102186, DSOT_Giro(0.469873, -0.048608, 0.000000)
   component 1.050000, 0.102186, DSOT_Giro(0.286245, -0.081013, 0.000000)
                     
   texture      {
     DSOT_PielBasica
   }
   #if ( DSOT_POV3_1 = off )
   texture      {
     pigment    {
       object   {
         blob  { 
           threshold    0.5
           sphere       {
             DSOT_Giro(0.5,-0.1,0),0.2,1
           }
           sphere       {
             DSOT_Giro(0.4,-0.15,0),0.2,1
           }
           sphere       {
             DSOT_Giro(0.3,-0.20,0),0.3,1
           }
           sphere       {
             DSOT_Giro(0.2,-0.20,0),0.3,1
           }
           sphere       {
             DSOT_Giro(0.1,-0.20,0),0.3,1
           }
            sphere       {
             DSOT_Giro(0.0,-0.25,0),0.3,1
           }
            sphere       {
             DSOT_Giro(0.0,-0.30,0),0.3,1
           }
        }
         color    rgbt 1
         DSOT_ColorBajoAbdomen
       }
     }
     finish { ambient 0.3 diffuse 0.7 }   
   }   
   #end
   texture {
      pigment {
        cylindrical
        rotate          90*x
        scale           0.01
        scale           1*y+2*x+1*z
        translate       -0.4*x+0.03*y
        pigment_map {
          [ 0.1 color rgbt 1 ]
          [ 0.3 color Gray50 ]
          [ 0.5 color Gray10 ]
        }
        turbulence      0.5
      }
      finish { ambient 0.3 diffuse 0.7 }
   }
}

blob {
   threshold 0.6
   component 1.000000, 0.075542, <-0.660063, -0.020000, -0.001055>
   component 1.000000, 0.098164, <-0.592321, -0.018694, 0.001055>
   component 1.000000, 0.077732, <-0.512152, 0.010591, 0.000000>
   component 1.000000, 0.094264, <-0.548017, -0.025274, 0.000000>

   texture      {
     DSOT_PielBasica
   }
   texture {
      pigment {
        gradient y   
        turbulence      0.02
        pigment_map      {
          [ 0.010 color Gray15        ]
          [ 0.010 color rgbt 1        ]
        }
        translate       -0.025*y
      }
      finish { ambient 0.3 diffuse 0.7 }
   }
   texture {
      pigment {
        cylindrical
        rotate          90*x
        scale           0.01
        scale           0.3*y+3*x+1.5*z
        translate       -0.60*x+0.01*y
        pigment_map {
          [ 0.1 color rgbt 1 ]
          [ 0.3 color Gray15 ]
        }
        turbulence      0.2
      }
      finish { ambient 0.3 diffuse 0.7 }
   }
}

blob {
   threshold 0.6
   component 1.000000, 0.075542, <-0.660063, -0.020000, -0.001055>
   component 1.000000, 0.098164, <-0.592321, -0.029494, 0.001055>
   component 1.000000, 0.077732, <-0.500000, -0.050000, 0.000000>
   component 1.000000, 0.094264, <-0.548017, -0.014874, 0.000000>

   texture      {
     DSOT_PielBasica
   }
   texture {
      pigment {
        gradient y   
        turbulence      0.02
        pigment_map      {
          [ 0.010 color DimGray       ]
          [ 0.010 color rgbt 1        ]
        }
        translate       -0.025*y
      }
      finish { ambient 0.3 diffuse 0.7 }
   }
}

blob {
   threshold 0.6
   component 1.000000, 0.041577, DSOT_Giro(0.025000, 0.175000, 0.000000)
   component 1.000000, 0.034571, DSOT_Giro(0.175000, 0.175000, 0.000000)
   component 1.000000, 0.052657, DSOT_Giro(0.125000, 0.175000, 0.000000)
   component 1.000000, 0.052657, DSOT_Giro(0.075000, 0.175000, 0.000000)
   component 1.000000, 0.032350, DSOT_Giro(0.125527, 0.292405, 0.000000)
   component 1.000000, 0.032044, DSOT_Giro(0.047468, 0.231224, 0.000000)
   component 1.000000, 0.032044, DSOT_Giro(0.068565, 0.254430, 0.000000)
   component 1.000000, 0.033842, DSOT_Giro(0.093882, 0.277637, 0.000000)
   component 1.000000, 0.032044, DSOT_Giro(0.032700, 0.208017, 0.000000)
   component 1.000000, 0.032350, DSOT_Giro(0.155063, 0.281857, 0.000000)
   component 1.000000, 0.032350, DSOT_Giro(0.165612, 0.250211, 0.000000)
   component 1.000000, 0.032350, DSOT_Giro(0.163502, 0.218565, 0.000000)
   component 1.000000, 0.032350, DSOT_Giro(0.182489, 0.191139, 0.000000)
   component 1.000000, 0.034571, DSOT_Giro(0.201477, 0.159494, 0.000000)
   component 1.000000, 0.034706, DSOT_Giro(0.098101, 0.237553, 0.000000)
   component 1.000000, 0.034706, DSOT_Giro(0.127637, 0.258650, 0.000000)
   component 1.000000, 0.034706, DSOT_Giro(0.133966, 0.224895, 0.000000)
   component 1.000000, 0.034706, DSOT_Giro(0.074895, 0.212236, 0.000000)
   component 1.000000, 0.034706, DSOT_Giro(0.108650, 0.203797, 0.000000)
   component 1.000000, 0.034706, DSOT_Giro(0.150844, 0.199578, 0.000000)
   component 1.000000, 0.022218, DSOT_Giro(0.182489, 0.220675, 0.000000)

   texture {
     DSOT_PielBasica
   }
}

blob {
   threshold 0.6
   component 1.000000, 0.045750, <-0.203587, -0.030000, -0.148734>
   component 1.000000, 0.052080, <-0.098101, -0.031148, -0.168480>
   component 1.000000, 0.052012, <-0.148734, -0.030000, -0.150844>
   component 1.000000, 0.031421, <-0.079114, -0.060879, -0.290239>
   component 1.000000, 0.031421, <-0.091772, -0.046721, -0.256260>
   component 1.000000, 0.031421, <-0.095992, -0.030000, -0.222152>
   component 1.000000, 0.039786, <-0.095992, -0.038227, -0.188301>
   component 1.000000, 0.031421, <-0.110759, -0.055216, -0.276081>
   component 1.000000, 0.031421, <-0.142405, -0.049553, -0.259091>
   component 1.000000, 0.031421, <-0.164557, -0.038227, -0.242616>
   component 1.000000, 0.031421, <-0.187764, -0.038227, -0.217300>
   component 1.000000, 0.031421, <-0.203587, -0.030000, -0.188397>
   component 1.000000, 0.040969, <-0.129747, -0.030000, -0.188397>
   component 1.000000, 0.040969, <-0.154008, -0.038227, -0.208861>
   component 1.000000, 0.040969, <-0.129747, -0.043890, -0.233607>
   component 1.000000, 0.040328, <-0.176160, -0.029732, -0.175559>

   texture {
     DSOT_PielBasica
   }
   translate    <+0.203587,0.030, 0.148734>
   rotate       AnguloIzquierdo*x
   translate    <-0.203587,-0.030,-0.148734>
}

blob {
   threshold 0.6
   component 1.000000, 0.045750, <-0.203587, -0.030000, 0.148734>
   component 1.000000, 0.056208, <-0.098101, -0.030000, 0.152954>
   component 1.000000, 0.052012, <-0.148734, -0.030000, 0.150844>
   component 1.000000, 0.031421, <-0.079114, -0.049553, 0.293070>
   component 1.000000, 0.031421, <-0.091772, -0.046721, 0.259091>
   component 1.000000, 0.031421, <-0.095992, -0.036811, 0.226528>
   component 1.000000, 0.031421, <-0.095992, -0.030000, 0.194726>
   component 1.000000, 0.031421, <-0.110759, -0.046721, 0.278912>
   component 1.000000, 0.031421, <-0.142405, -0.038227, 0.259091>
   component 1.000000, 0.031421, <-0.171941, -0.041058, 0.242102>
   component 1.000000, 0.031421, <-0.186709, -0.032563, 0.210954>
   component 1.000000, 0.031421, <-0.203587, -0.030000, 0.188397>
   component 1.000000, 0.040969, <-0.129747, -0.030000, 0.188397>
   component 1.000000, 0.040969, <-0.167722, -0.029732, 0.188301>
   component 1.000000, 0.040969, <-0.129747, -0.035395, 0.233607>
   component 1.000000, 0.032044, <-0.158228, -0.032563, 0.213786>

   texture {
     DSOT_PielBasica
   }
   translate    <+0.203587,0.030,-0.148734>
   rotate       AnguloDerecho*x
   translate    <-0.203587,-0.030,+0.148734>   
}

blob {
   threshold 0.6
   component 1.000000, 0.051822, DSOT_Giro(1.006329, 0.010549, 0.000000)
   component 1.000000, 0.044437, DSOT_Giro(1.069620, 0.010549, 0.251055)
   component 1.000000, 0.051822, DSOT_Giro(1.048523, 0.010549, 0.200422)
   component 1.000000, 0.051822, DSOT_Giro(1.031646, 0.010549, 0.149789)
   component 1.000000, 0.051822, DSOT_Giro(1.018987, 0.010549, 0.103376)
   component 1.000000, 0.051822, DSOT_Giro(1.006329, 0.010549, 0.056962)
   component 1.000000, 0.081937, DSOT_Giro(0.879747, 0.010549, 0.002110)
   component 1.000000, 0.075412, DSOT_Giro(0.909283, 0.010549, 0.052743)
   component 1.000000, 0.051822, DSOT_Giro(0.938819, 0.010549, 0.103376)
   component 1.000000, 0.051822, DSOT_Giro(0.964135, 0.010549, 0.158228)
   component 1.000000, 0.051822, DSOT_Giro(1.002110, 0.010549, 0.196203)
   component 1.000000, 0.044437, DSOT_Giro(1.031646, 0.010549, 0.234177)
   component 1.000000, 0.075412, DSOT_Giro(0.909283, 0.010549, -0.052743)
   component 1.000000, 0.051822, DSOT_Giro(0.938819, 0.010549, -0.103376)
   component 1.000000, 0.051822, DSOT_Giro(0.964135, 0.010549, -0.158228)
   component 1.000000, 0.051822, DSOT_Giro(1.002110, 0.010549, -0.196203)
   component 1.000000, 0.044437, DSOT_Giro(1.031646, 0.010549, -0.234177)
   component 1.000000, 0.044437, DSOT_Giro(1.069620, 0.010549, -0.251055)
   component 1.000000, 0.051822, DSOT_Giro(1.048523, 0.010549, -0.200422)
   component 1.000000, 0.051822, DSOT_Giro(1.031646, 0.010549, -0.149789)
   component 1.000000, 0.051822, DSOT_Giro(1.018987, 0.010549, -0.103376)
   component 1.000000, 0.051822, DSOT_Giro(1.006329, 0.010549, -0.056962)
   component 1.000000, 0.081937, DSOT_Giro(0.959916, 0.010549, -0.002110)
   component 1.000000, 0.075412, DSOT_Giro(0.968354, 0.010549, 0.069620)
   component 1.000000, 0.075412, DSOT_Giro(0.968354, 0.010549, -0.078059)
   component 1.000000, 0.051822, DSOT_Giro(0.989451, 0.010549, -0.137131)
   component 1.000000, 0.051822, DSOT_Giro(0.989451, 0.010549, 0.128692)
   texture {
     DSOT_PielBasica
   }
}
}
#end
