// This file is licensed under the terms of the CC-LGPL.
//
// El delfin fue creado originalmente con el programa
// "Blob Sculptor 2.0b" de AlfonsoHermida y otros (The Blob Team)
// ultima version en 1994
// compatible FreeDOS y WindowsXP
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com
// Apdo. 964-1250 Escaz, San Jos, Costa Rica 
// dedicado a Jess y Mara...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 22 noviembre 2010
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
// El objeto creado por la macro es un delfin.  Se ubica
// segun DSOT_DelfinSportOceanTravel(0,0,0,0,0) tiene coordenadas
// Minimo <  -736,   -255,  -322>*L
// Maximo <  1114,    325,   324>*L
// el origen se encuentra debajo de la parte delantera
// de la aleta dorsal, en el interior
//
// Los parametros de la macro
// DSOT_DelfinSportOceanTravel
//        ( AnguloSelfCola, SitaColeteo, FiColeteo,  
//                AnguloDerecho, AnguloIzquierdo ) 
// AnguloSelfCola       : rotacion de la cola sobre su propio eje
// SitaColeteo          : define el angulo o sentido del coleteo
//              si es igual a 0, el EjeRotacion es y+
//              el angulo Sita Coleteo gira "EjeRotacion" 
// FiColeteo            : establece el giro en el EjeRotacion
// AnguloDerecho        : giro de la aleta lateral derecha (del delfin)
//              en x+
// AnguloIzquierdo      : giro de la aleta lateral izquierda (del delfin)
//              en x+ 
//
// acepta los siguientes modificadores
//   #declare DSOT_PielBasica           = texture {...}
//             para la textura de la piel
//   #declare DSOT_ColorBajoAbdomen     = color
// Lamentablemente el ColorBajoAbdomen, se permite unicamente como color
// sin modificadores.
//   #declare DSOT_POV3_1               = on;
// Provoca simplificaciones para garantizar compatibilidad con POVRay3.1.
// En algunas versiones de POVRay se activa automticamente.
//
// Para colocarlo simplemente 
// #include "DSOT.inc"
// object       {
//   DSOT_DelfinSportOceanTravel(0,0,0,0,0)
// }
// o con modificadores podria un delfin de abdomen mas blanco...
// #declare DSOT_ColorBajoAbdomen       = color Gray50;
// #declare DSOT_PielBasica             = texture { 
//        pigment {color DimGray} 
// }
// #include "DelfinSOT.inc"
// object       {
//   DSOT_DelfinSportOceanTravel(0,0,0,0,0)
// }
// una simple animacion de coleteo sube y baja
// #include "DelfinSOT.inc"
// object       {
//   DSOT_DelfinSportOceanTravel
//        (0,90,20*sin(2*pi*clock),20*sin(2*pi*clock),20*sin(2*pi*clock))
// } 
// Nota: el noventa gira el EjeRotacion, para producir el coleteo
//      sube y baja, si 0 seria coleteo de izquierda a derecha
//

#include "colors.inc"
#include "DSOT.inc"

 
#declare DSOT_OjoAbsoluto            = 256;
#declare DSOT_VecesCentroAbsoluto    = 10;     
#declare DSOT_L                      = 0.001;
camera {
  location <   0,  0, 
        -( DSOT_VecesCentroAbsoluto+1 )*DSOT_OjoAbsoluto >*DSOT_L
  look_at  <   0,  0, 
        -DSOT_VecesCentroAbsoluto*DSOT_OjoAbsoluto >*DSOT_L  
}         
light_source    {
         < 500  , 500   , -3000 >*DSOT_L
         White
}
background      {
         SeaGreen
}    

#local   DSOT_FactorAcercamiento     = 1.1;
               
object  {          
  DSOT_DelfinSportOceanTravel( 30, 30, 20, -45, 45 )
  translate       -( DSOT_VecesCentroAbsoluto+1 )
                        *( DSOT_FactorAcercamiento-1 )
        /( DSOT_FactorAcercamiento )*DSOT_OjoAbsoluto*DSOT_L*z   
    
}  


