// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com
// Apdo. 964-1250 Escaz, San Jos, Costa Rica 
// dedicado a Jess y Mara...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 17 enero 2010
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
//
// "RCMH_Rallador.inc" crea un rallador simple de cocina
// con cuatro diferentes tipos de hojas
// Sus dimensiones son:
// Alto                 = 154*L
// AnchoFrontal         = 65*L
// AnchoLateral         = 47*L
// Su ubicacion primaria es con la base centrada en el origen
// su Ancho Frontal apuntando hacia z-
//
// Para ponerlo en pantalla simplemente utilice la macro default
// #include "RCMH_Rallador.inc"
// object { RCMH_Rallador() }
// Otra alternativa disponible es utilizar la macro:
// object { RCMH_RalladorCocinaMultiHoja
//              ( TexturaMetal, TexturaPlastico, TexturaAgarradera ) }  
//      TexturaMetal    : textura de la zona de rallado
//      TexturaPlastico : textura de la base rectangular de la agarradera
//      TexturaAgarradera       : textura de la curva de la agarradera
//
// Para accesar a las siguientes texturas basicas que
// no deberian modificarse, las variables son
// #declare RCMH_TexturaMetalBase
// #declare RCMH_TexturaPlasticoBase 
// #declare RCMH_TexturaAgarraderaBase
// Si usted desea modificar la textura default, utilice 
// las siguientes variables tipo "#ifndef"
// #declare RCMH_TexturaMetalDefault
// #declare RCMH_TexturaPlasticoDefault
// #declare RCMH_TexturaAgarraderaDefault
// Por ejemplo 
// #include "RCMH_Rallador.inc"
// #declare CustomTextura               = texture       {
//   pigment            { Cyan }
// }
// #declare RCMH_TexturaPlasticoDefault = texture       {
//   average
//   texture_map   {
//      [ 0.5 RCMH_TexturaMetalBase ]
//      [ 0.5 CustomTextura         ]
//   }
// }
// object { RCMH_Rallador() }
// Donde CustomTextura seria una textura de su propia creacion
//


#include "textures.inc"
                        
                        
                        
#macro RCMH_RalladorCocinaMultiHoja
                ( TexturaMetal, TexturaPlastico, TexturaAgarradera )
   #local L                     = 0.001;
   #local AnchoBase             = 61*L;
   #local ProfundidadBase       = 43*L;
   #local AnchoSuperior         = 50*L;
   #local ProfundidadSuperior   = 32*L;
   #local AlturaSuperior        = 121*L;
   #local Base0                 =
                < AnchoBase/2, 0, ProfundidadBase/2 >;
   #local Superior0             =
                < AnchoSuperior/2, AlturaSuperior, ProfundidadSuperior/2 >;
   #local TotalFilasFrente      = 8;
   #local FilasUtilesFrente     = 7;
   #local FilaInicialFrente     =
                ( TotalFilasFrente-FilasUtilesFrente )/2;
   #local TotalColumnasFrente   = 13;
   #local ColumnasUtilesFrente  = 9;
   #local ColumnaInicialFrente  =
                        ( TotalColumnasFrente-ColumnasUtilesFrente )/2;
   #local TotalFilasDetras      = 29;
   #local FilasUtilesDetras     = 23;
   #local FilaInicialDetras     =
                ( TotalFilasDetras-FilasUtilesDetras )/2;
   #local TotalColumnasDetras   = 15;
   #local ColumnasUtilesDetras  = 11;
   #local ColumnaInicialDetras  =
                        ( TotalColumnasDetras-ColumnasUtilesDetras )/2;
   #local TotalFilasLDerec      = 51;
   #local FilasUtilesLDerec     = 41;
   #local FilaInicialLDerec     =
                ( TotalFilasLDerec-FilasUtilesLDerec )/2;
   #local TotalColumnasLDerec   = 17;
   #local ColumnasUtilesLDerec  = 13;
   #local ColumnaInicialLDerec  =
                        ( TotalColumnasLDerec-ColumnasUtilesLDerec )/2;
   #macro RCMH_UbicarPuntoPlano ( Fila, Columna, TotalFilas, TotalColumnas,
                DirHorizontal, DirVertical, ContraccionSuperior )
      DirVertical*Fila/( TotalFilas-1 )
      +DirHorizontal*Columna/( TotalColumnas-1 )
      *( 1-ContraccionSuperior*Fila/( TotalFilas-1 ) )
   #end

   #macro RCMH_Mod ( A, B )
     A-B*floor( A/B )
   #end

   union        {
     #local DienteAncho         = 5*L;
     #local DienteAlto          = 10*L;
     #local DienteProfundidad   = 2.5*L;
     #local EscalaDiente        =
                < DienteAncho, DienteAlto, DienteProfundidad >/2;
     difference   {
       polygon    {
         5,
         Base0*< -1, +1, -1 >,
         Base0*< +1, +1, -1 >,
         Superior0*< +1, +1, -1 >,
         Superior0*< -1, +1, -1 >,
         Base0*< -1, +1, -1 >
       }
       #local C         = 0;
       #while ( C < FilasUtilesFrente )
         #local D       = 0;
         #while ( D < ColumnasUtilesFrente )
           #local Piv   = RCMH_Mod( C+D, 2 );
           #if ( Piv = 0 )
             sphere       {
               0        , 1
               scale    EscalaDiente
               translate
                 RCMH_UbicarPuntoPlano
                  ( C+FilaInicialFrente, D+ColumnaInicialFrente,
                    TotalFilasFrente, TotalColumnasFrente,
                    AnchoBase*x, ( Superior0-Base0 )*<-1,1,-1>,
                    1-AnchoSuperior/AnchoBase )+Base0*<-1,1,-1>
             }
           #end
           #local D     = D+1;
         #end
         #local C       = C+1;
       #end
     }
     union      {
       #local C         = 0;
       #while ( C < FilasUtilesFrente )
         #local D       = 0;
         #while ( D < ColumnasUtilesFrente )
           #local Piv   = RCMH_Mod( C+D, 2 );
           #if ( Piv = 0 )
             difference         {
               sphere           {
                 0        , 1
               }
               sphere           {
                 0        , 0.98
               }
               plane            {
                 -z       , 0
               }
               cylinder         {
                 0        , -z          , 0.75
                 translate      0.5*y
               }
               scale    EscalaDiente
               translate
                   RCMH_UbicarPuntoPlano
                    ( C+FilaInicialFrente, D+ColumnaInicialFrente,
                      TotalFilasFrente, TotalColumnasFrente,
                      AnchoBase*x, ( Superior0-Base0 )*<-1,1,-1>,
                      1-AnchoSuperior/AnchoBase )+Base0*<-1,1,-1>
             }
           #end
           #local D     = D+1;
         #end
         #local C       = C+1;
       #end
     }
     #local EscalaEsferita      = 2.0*L;
     #local FraccionCuchilla    = 0.5;
     #local S                   = seed( 2563 );
     difference {
       polygon    {
         5,
         Base0*< -1, +1, +1 >,
         Base0*< +1, +1, +1 >,
         Superior0*< +1, +1, +1 >,
         Superior0*< -1, +1, +1 >,
         Base0*< -1, +1, +1 >
       }
       #local C         = 0;
       #while ( C < FilasUtilesDetras )
         #local D       = 0;
         #while ( D < ColumnasUtilesDetras )
           #local Piv   = RCMH_Mod( C+D, 2 );
           #if ( Piv = 0 )
             sphere       {
               0        , 1
               scale    EscalaEsferita
               translate
                 RCMH_UbicarPuntoPlano
                  ( C+FilaInicialDetras, D+ColumnaInicialDetras,
                    TotalFilasDetras, TotalColumnasDetras,
                    -AnchoBase*x, ( Superior0-Base0 )*<1,1,1>,
                    1-AnchoSuperior/AnchoBase )+Base0*<1,1,1>
             }
           #end
           #local D     = D+1;
         #end
         #local C       = C+1;
       #end
     }
     union      {
       #local C         = 0;
       #while ( C < FilasUtilesDetras )
         #local D       = 0;
         #while ( D < ColumnasUtilesDetras )
           #local Piv   = RCMH_Mod( C+D, 2 );
           #if ( Piv = 0 )
             difference   {
               sphere           {
                 0        , 1
               }
               sphere           {
                 0      , 0.98
               }
               plane            {
                 z      , 0
               }
               box              {
                 -<1,1,0>*FraccionCuchilla-z, <1,1,0>*FraccionCuchilla+z
                 rotate         90*rand( S )*z
               }
               scale    EscalaEsferita
               translate
                 RCMH_UbicarPuntoPlano
                  ( C+FilaInicialDetras, D+ColumnaInicialDetras,
                    TotalFilasDetras, TotalColumnasDetras,
                    -AnchoBase*x, ( Superior0-Base0 )*<1,1,1>,
                    1-AnchoSuperior/AnchoBase )+Base0*<1,1,1>
             }
           #end
           #local D     = D+1;
         #end
         #local C       = C+1;
       #end
     }
     #local TotalCuchillas  = 3;
     #local CuchillaInicial = 0.5;
     #local PInicial    = Base0*<1,1,0>;
     #local PFinal      = Superior0*<1,1,0>;
     #local LargoCuchilla       = 20*L;
     #local AltoCuchilla        = 7.0*L;
     #local ProfundidadCuchilla = 7.0*L;
     #local EscalaCuchillas     =
                < ProfundidadCuchilla, AltoCuchilla, LargoCuchilla >/2;
     difference {
       polygon    {
         5,
         Base0*< +1, +1, +1 >,
         Base0*< +1, +1, -1 >,
         Superior0*< +1, +1, -1 >,
         Superior0*< +1, +1, +1 >,
         Base0*< +1, +1, +1 >
       }
       #local C         = 0;
       #while ( C < TotalCuchillas )
         union                 {
           sphere              {
             0    , 1
           }
           difference          {
             cylinder     {
               -10*x, 10*x  , 2
             }
             cylinder     {
               -10*x, 10*x  , 1
             }
             plane      {
               z        , 0
               rotate   40*x
             }
             plane      {
               -z       , 0
               rotate   -40*x
             }
             translate  2*y
           }
           scale   EscalaCuchillas
           translate    PInicial+( PFinal-PInicial )*
                                ( C+CuchillaInicial )/TotalCuchillas
         }
         #local C       = C+1;
       #end
     }
     
     union {
       #local C         = 0;
       #while ( C < TotalCuchillas )
         difference             {
           difference                 {
             sphere              {
               0    , 1.1
             }
             plane                {
               -x         , -0.5
             }
             plane                {
               +x         , 0
             }
             plane                {
               -y          , 0
             }
           }
           difference                 {
             sphere              {
               0    , 1
             }
             plane                {
               -x         , -0.5
             }
           }
           scale   EscalaCuchillas
           translate    PInicial+( PFinal-PInicial )*
                                ( C+CuchillaInicial )/TotalCuchillas
         }
         #local C       = C+1;
       #end
     }
     #local EscalaEsferita      = 1.1*L;
     #local FraccionCuchilla    = 0.3;
     difference {
       polygon    {
         5,
         Base0*< -1, +1, +1 >,
         Base0*< -1, +1, -1 >,
         Superior0*< -1, +1, -1 >,
         Superior0*< -1, +1, +1 >,
         Base0*< -1, +1, +1 >
       }
       #local C         = 0;
       #while ( C < FilasUtilesLDerec )
         #local D       = 0;
         #while ( D < ColumnasUtilesLDerec )
           #local Piv   = RCMH_Mod( C+D, 2 );
           #if ( Piv = 0 )
             sphere       {
               0        , 1
               scale    EscalaEsferita
               translate
                 RCMH_UbicarPuntoPlano
                  ( C+FilaInicialLDerec, D+ColumnaInicialLDerec,
                    TotalFilasLDerec, TotalColumnasLDerec,
                    -ProfundidadBase*z, ( Superior0-Base0 )*<-1,1,1>,
                    1-ProfundidadSuperior/ProfundidadBase )+Base0*<-1,1,1>
             }
           #end
           #local D     = D+1;
         #end
         #local C       = C+1;
       #end
     }
     union      {
       #local C         = 0;
       #while ( C < FilasUtilesLDerec )
         #local D       = 0;
         #while ( D < ColumnasUtilesLDerec )
           #local Piv   = RCMH_Mod( C+D, 2 );
           #if ( Piv = 0 )
             difference   {
               sphere           {
                 0        , 1
               }
               sphere           {
                 0      , 0.95
               }
               plane            {
                 z      , 0
               }
               box              {
                 -<1,1,0>*FraccionCuchilla-z, <1,1,0>*FraccionCuchilla+z
                 rotate         90*rand( S )*z
               }
               scale    EscalaEsferita
               translate
                 RCMH_UbicarPuntoPlano
                  ( C+FilaInicialLDerec, D+ColumnaInicialLDerec,
                    TotalFilasLDerec, TotalColumnasLDerec,
                    -ProfundidadBase*z, ( Superior0-Base0 )*<-1,1,1>,
                    1-ProfundidadSuperior/ProfundidadBase )+Base0*<-1,1,1>
             }
           #end
           #local D     = D+1;
         #end
         #local C       = C+1;
       #end
     }
     #local RadioCilindroBase   = 2*L;
     #local PuntoCilindro       = Base0+RadioCilindroBase*<1,0,1>;
     cylinder   {
       PuntoCilindro, PuntoCilindro*<1,1,-1>, RadioCilindroBase
     }
     sphere     {
       PuntoCilindro, RadioCilindroBase
     }
     cylinder   {
       PuntoCilindro*<1,1,-1>, PuntoCilindro*<-1,1,-1>, RadioCilindroBase
     }
     sphere     {
       PuntoCilindro*<1,1,-1>, RadioCilindroBase
     }
     cylinder   {
       PuntoCilindro*<-1,1,-1>, PuntoCilindro*<-1,1,1>, RadioCilindroBase
     }
     sphere     {
       PuntoCilindro*<-1,1,-1>, RadioCilindroBase
     }
     cylinder   {
       PuntoCilindro, PuntoCilindro*<-1,1,1>, RadioCilindroBase
     }
     sphere     {
       PuntoCilindro*<-1,1,1>, RadioCilindroBase
     }
     #local AltoBaseAgarre      = 7*L;
     #local GruesoXAgarre       = 5*L;
     #local GruesoZAgarre       = 7*L;
     #local DiametroBordeAgarre = 4*L;
     union      {
       difference       {
         union          {
           box          {
             < AnchoSuperior+GruesoXAgarre,
               0, ProfundidadSuperior+GruesoZAgarre-DiametroBordeAgarre >/2,
             <-AnchoSuperior-GruesoXAgarre, 2*AltoBaseAgarre,
                 -ProfundidadSuperior-GruesoZAgarre+DiametroBordeAgarre >/2
           }
           box          {
             < AnchoSuperior+GruesoXAgarre-DiametroBordeAgarre,
               0, ProfundidadSuperior+GruesoZAgarre >/2,
             <-AnchoSuperior-GruesoXAgarre+DiametroBordeAgarre,
                2*AltoBaseAgarre, -ProfundidadSuperior-GruesoZAgarre >/2
           }
           #local PuntoCilindro   =
                  < AnchoSuperior+GruesoXAgarre-DiametroBordeAgarre, 0,
                    ProfundidadSuperior+GruesoZAgarre-DiametroBordeAgarre >/2;
           cylinder       {
             PuntoCilindro,
             PuntoCilindro+AltoBaseAgarre*y,
             DiametroBordeAgarre/2
           }
           cylinder       {
             PuntoCilindro*<1,1,-1>,
             PuntoCilindro*<1,1,-1>+AltoBaseAgarre*y,
             DiametroBordeAgarre/2
           }
           cylinder       {
             PuntoCilindro*<-1,1,1>,
             PuntoCilindro*<-1,1,1>+AltoBaseAgarre*y,
             DiametroBordeAgarre/2
           }
           cylinder       {
             PuntoCilindro*<-1,1,-1>,
             PuntoCilindro*<-1,1,-1>+AltoBaseAgarre*y,
             DiametroBordeAgarre/2
           }

         }
         box            {
           < AnchoSuperior-GruesoXAgarre,
                -0.01*AltoBaseAgarre, ProfundidadSuperior-GruesoZAgarre >/2,
           <-AnchoSuperior+GruesoXAgarre,
                 2*1.01*AltoBaseAgarre,-ProfundidadSuperior+GruesoZAgarre >/2
         }

         translate      AlturaSuperior*y
       }
       texture  {
         TexturaPlastico
       }
     }
     #local ProfundidadAgarradera       = 14*L;
     #local RadioCurvoAgarradera        = 15*L;
     #local GruesoAgarradera            = 2*L;
     #local AlturaAgarradera            = 24*L;
     union      {
       difference       {
         cylinder       {
           -ProfundidadAgarradera*z/2,
            ProfundidadAgarradera*z/2,
           RadioCurvoAgarradera
         }
         cylinder       {
           -1.01*ProfundidadAgarradera*z/2,
            1.01*ProfundidadAgarradera*z/2,
           RadioCurvoAgarradera-GruesoAgarradera
         }
         plane          {
           x    , 0
         }
         plane          {
           y    , 0
         }
         translate ( AlturaSuperior+AltoBaseAgarre )*y
                +( AlturaAgarradera-RadioCurvoAgarradera )*y
                +( AnchoSuperior/2-RadioCurvoAgarradera+GruesoAgarradera/2 )*x
       }
       difference       {
         cylinder       {
           -ProfundidadAgarradera*z/2,
            ProfundidadAgarradera*z/2,
           RadioCurvoAgarradera
         }
         cylinder       {
           -1.01*ProfundidadAgarradera*z/2,
            1.01*ProfundidadAgarradera*z/2,
           RadioCurvoAgarradera-GruesoAgarradera
         }
         plane          {
           x    , 0
         }
         plane          {
           y    , 0
         }
         rotate         180*y
         translate ( AlturaSuperior+AltoBaseAgarre )*y
                +( AlturaAgarradera-RadioCurvoAgarradera )*y
                -( AnchoSuperior/2-RadioCurvoAgarradera+GruesoAgarradera/2 )*x
       }
       box      {
         < ( -AnchoSuperior-GruesoAgarradera )/2,
            0, -ProfundidadAgarradera/2 >,
         < ( -AnchoSuperior+GruesoAgarradera )/2,
            AlturaAgarradera-RadioCurvoAgarradera, +ProfundidadAgarradera/2 >
         translate      ( AlturaSuperior+AltoBaseAgarre )*y
       }
       box      {
         < ( +AnchoSuperior+GruesoAgarradera )/2,
            0, -ProfundidadAgarradera/2 >,
         < ( +AnchoSuperior-GruesoAgarradera )/2,
            AlturaAgarradera-RadioCurvoAgarradera, +ProfundidadAgarradera/2 >
         translate      ( AlturaSuperior+AltoBaseAgarre )*y
       }
       box      {
         < -AnchoSuperior/2+RadioCurvoAgarradera-GruesoAgarradera/2,
           0, -ProfundidadAgarradera/2 >,
         < +AnchoSuperior/2-RadioCurvoAgarradera+GruesoAgarradera/2,
           GruesoAgarradera,
           +ProfundidadAgarradera/2 >
         translate      ( AlturaAgarradera+AlturaSuperior+AltoBaseAgarre
                                -GruesoAgarradera )*y
       }
       texture  {
         TexturaAgarradera
       }
     }
     translate  RadioCilindroBase*y
     texture    {
       TexturaMetal
     }
   }
#end

#local   TexturaSilver          = texture       {
  pigment       { Silver*0.9 }
}

#declare RCMH_TexturaMetalBase  = texture       {
  average 
  turbulence    0.5
  texture_map   {
    [ 0.5  TexturaSilver  normal { granite 2.0  }  ]
    [ 0.5  Bright_Bronze  normal { bumps 2.0    }  ]
  }
}

#ifndef ( RCMH_TexturaMetalDefault )  
  #declare RCMH_TexturaMetalDefault     = texture { 
                RCMH_TexturaMetalBase }
#end

#declare RCMH_TexturaPlasticoBase       = texture {
  Rosewood
}

#declare RCMH_TexturaAgarraderaBase     = texture {
  Rosewood
}

#ifndef ( RCMH_TexturaPlasticoDefault )
  #declare RCMH_TexturaPlasticoDefault  = texture {
    RCMH_TexturaPlasticoBase
  }      
#end

#ifndef ( RCMH_TexturaAgarraderaDefault )
  #declare RCMH_TexturaAgarraderaDefault        = texture       {
    RCMH_TexturaAgarraderaBase
  }
#end

#macro RCMH_Rallador()  
  object {
    RCMH_RalladorCocinaMultiHoja( RCMH_TexturaMetalDefault, 
           RCMH_TexturaPlasticoDefault, RCMH_TexturaAgarraderaDefault )
  }
#end
